<?php


class RadioactivityDeferredIncidentStorage extends RadioactivityIncidentStorage {

  const REQUIRE_BOOTSTRAP = true;

  /**
   * Constructor
   */
  public function __construct() {
  }

  /**
   * add incident to the deferred storage
   * @entity_energy energy by entity id
   */
  public function addIncident($incident) {

    db_insert('radioactivity_deferred_storage')
      ->fields(array(
        'entity_type' => $incident->entityType,
        'field_name ' => $incident->fieldName,
        'bundle ' => $incident->bundle,
        'entity_id' => $incident->entityId,
        'energy' => $incident->energy,
        'emission_time' => $incident->time,
      ))
      ->execute(); 
  }


  /**
   * Process incidents in the deferred queue 
   */
  public function processIncidents() {

    // grab rows from table and push them to fields

    $query = db_select("radioactivity_deferred_storage", "rds")
      ->fields("rds", array("entity_type", "bundle", "entity_id", "field_name"))
      ->groupby("rds.entity_type")
      ->groupby("rds.bundle")
      ->groupby("rds.entity_id");

    $query->addexpression("sum(rds.energy)", "energy");
    $query->addexpression("max(rds.emission_time)", "emission_time");

    $result = $query->execute();

    $now = time() - 10;

    while ($row = $result->fetch()) {
      _radioactivity_update_energy(
        $row->entity_type,
        $row->bundle,
        $row->field_name,
        $row->entity_id,
        $row->energy,
        $row->emission_time
      );

    }

    // Flush the processed entries from the db
    db_delete("radioactivity_deferred_storage")
      ->execute();


  }


}

