
(function ($) {
  Drupal.behaviors.radioactivity = {
    attach: function (context, settings) {
      
      var element = document.createElement('canvas');
      var canvas = $(element);  
      var width = 400;
      var height = 300;
      
      canvas.attr({
        id: "radioactivity-graph",
        width: width,
        height: height, 
      });
      
      canvas.css({backgroundColor:"#EEE", width:width, height:height, padding:"0", margin:"5px"}); 
      
      $('#ctools-export-ui-edit-item-form .form-item-description').append(canvas);
      $('#edit-half-life').bind("change", this.updateGraph)
      $('#edit-granularity').bind("change", this.updateGraph);
      
      this.updateGraph();
    },

    updateGraph: function() { 
      var element = document.getElementById('radioactivity-graph');
      var c = element.getContext('2d');
      c.width = parseInt($(element).css("width"));
      c.height = parseInt($(element).css("height"));
      c.clearRect(0, 0, c.width, c.height);
      var g = $("#edit-granularity").val();
      var hl = $("#edit-half-life").val();
   
      c.beginPath();
      c.lineWidth = 1;
      c.strokeStyle = "#CCC";
      c.moveTo(0, Math.round(c.height * 0.5) + 0.5);
      c.lineTo(c.width, Math.round(c.height * 0.5) + 0.5);
      c.stroke();

      c.font = "normal 12px sans-serif";
      c.textAlign = "left";
      c.textBaseline = "top";
      c.fillText("100%", 0, 0);
      c.textBaseline = "middle";
      c.fillText("50%", 0, c.height * 0.5);
      c.textBaseline = "bottom";
      c.textAlign = "center"; 

      var scale = 48;
      if (hl < 60 * 60 * 3) {
        scale = 3;
      } else if (hl < 60 * 60 * 6) {
        scale = 6;
      } else if (hl < 60 * 60 * 12) {
        scale = 12;
      } else if (hl < 60 * 60 * 24) {
        scale = 24;
      }
        
      var steps = 6;
      var f = (c.width / steps);
      var y = c.height - 2;
      var h = 0, ih = scale / steps;   
      
      for (var x = 0; x <= steps; x++) {
        var t = Math.round(x * f);
        c.beginPath();
        c.moveTo(t, 0);
        c.lineTo(t, c.height);
        c.stroke();
        if (x == 0) {
          c.textAlign = "left";
        } else if (x == steps) {
          c.textAlign = "right";
        } else {
          c.textAlign = "center";
        }
        c.fillText(h.toFixed(1) + "h", t, y);
        h += ih;
      }

      //Drupal.behaviors.radioactivity.renderGraph(c, "#AAA", 21600, scale * 60 * 60);
      Drupal.behaviors.radioactivity.renderGraph(c, "#F00", hl, scale * 60 * 60);

    },

    renderGraph: function(c, color, hl, scale) {
      
      c.lineWidth = 1;
      c.strokeStyle = color;
  
      var t = (c.width / scale) * hl;
      
      c.beginPath();
      c.moveTo(t, 0);
      c.lineTo(t, c.height);
      c.stroke();
    
      var h = c.height;
      var w = c.width;
      var e = h;
      var f = Math.pow(2, -(scale / w) / hl);

      if (this.interval != null) {
        clearInterval(this.interval);
      }
      
      Drupal.behaviors.radioactivity.t = 0;

      this.interval = setInterval(function() {
        Drupal.behaviors.radioactivity.subRenderGraph(c, hl, scale);
      }, 10);
    },
  
    subRenderGraph: function (c, hl, scale) {
      if (!this.t) this.t = 0;
      var h = c.height;      
      var w = c.width;
      var t = this.t;
      this.t++;
      c.beginPath();
      // e = e * Math.pow(2, (t1 - t2) / hl);
      // et = 
      // y = x^2
      // x = sqrt(y)
      var e = h * Math.pow(2, ((t-1) * (-scale / c.width)) / hl);
      c.moveTo(t - 1, h - e);
      e = h * Math.pow(2, (t * (-scale / c.width)) / hl);
      c.lineTo(t, h - e);
      c.stroke();
    }
  }

})(jQuery);


