<?php


function radioactivity_admin_general_form() {

  module_load_include("inc", "radioactivity", "radioactivity-bootstrap");

  radioactivity_check_warnings();

  $vars = array(
    "@file" => _radioactivity_get_config_file_path(),
  );

  $form = array();

  $form['security'] = array(
    '#type' => 'fieldset',
    '#disabled' => false,
    '#title' => t('Security'),
    '#description' => t('Radioactivity security features prevent manipulation of popularity by 3rd parties.'),
  );

  $form['security']['radioactivity_checksum_salt'] = array(
    '#type' => 'textfield',
    '#title' => t('Salt for checksums'),
    '#description' => t(
      'A string used to salt the data on eg. ajax callback. This should be as random and as long as possible.'
    ),
    '#size' => 128,
    '#required' => TRUE,
    '#default_value' => variable_get('radioactivity_checksum_salt', RADIOACTIVITY_CHECKSUM_SALT),
  );

  $form['security']['radioactivity_flood_protection'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable flood protection (not yet functional)'),
    '#disabled' => true,
    '#description' => t(
      'This prevents users from boosting entities by refreshing the page multiple times or by ' .
      'calling the callback function directory. With flood protection enabled Radioactivity ' .
      'metrics are also more accurate but consume more resources.'
    ),
    '#default_value' => variable_get('radioactivity_flood_protection', false),
  );


  $form['security']['radioactivity_flood_timeout'] = array(
    '#type' => 'textfield',
    '#title' => t('Flood protection timeout'),
    '#disabled' => true,
    '#description' => t(
      'How many minutes are required to pass between calls to emit energy for a single field. ' .
      'One incident per field per given amount of minutes.'
    ),
    '#size' => 5,
    '#default_value' => variable_get('radioactivity_flood_timeout', 15),
  );


  $form['assist'] = array(
    '#type' => 'fieldset',
    '#disabled' => false,
    '#title' => t('Configuration assist'),
    '#description' => t('Radioactivity configuration asssist provides easy configuration of high performance callbacks'),
  );

  $salt = variable_get('radioactivity_checksum_salt', RADIOACTIVITY_CHECKSUM_SALT);

  $cfg = <<<EOCFG
<?php
define("VAR_RADIOACTIVITY_CHECKSUM_SALT", "$salt");
EOCFG;

  $form['assist']['config'] = array(
    '#type' => 'textarea',
    '#title' => t('Configuration assist'),
    '#description' => t(
      'Copy the contents of this box to @file',
      $vars
    ),
    '#size' => 5,
    '#default_value' => $cfg
  );

  $form['assist']['auto'] = array( 
    '#type' => 'checkbox',
    '#title' => t('Try to create the file automatically'),
  );

  $form['save'] = array(
    '#type' => 'submit',
    '#value' => t('Save')
  );


  return $form;

}



function radioactivity_admin_general_form_submit($form_id, $form_state) {

  variable_set('radioactivity_checksum_salt', $form_state['values']['radioactivity_checksum_salt']);

  variable_set('radioactivity_flood_protection', isset($form_state['values']['radioactivity_flood_protection']) ? true : false);
  variable_set('radioactivity_flood_timeout', isset($form_state['values']['radioactivity_flood_timeout']) ? $form_state['values']['radioactivity_flood_timeout'] : 15 );


  if ($form_state['values']['auto']) {

    $file = drupal_get_path("module", "radioactivity") . "/radioactivity-bootstrap.cfg.inc";
    $cfg = $form_state['values']['config'];
    file_put_contents($file, $cfg);

  }

}


